@@ -164,6 +164,11 @@ class Chatter(PartialChatter):
         """The users display name."""
         return self._display_name
 
+    @property
+    def mention(self) -> str:
+        """Mentions the users display name by prefixing it with '@'"""
+        return f"@{self._display_name}"
+
     @property
     def colour(self) -> str:
         """The users colour. Alias to color."""
@@ -180,7 +185,7 @@ class Chatter(PartialChatter):
         if self._mod == 1:
             return True
 
-        return self.channel.name == self.display_name.lower()
+        return self.channel.name == self.name.lower()
 
     @property
     def is_turbo(self) -> Optional[bool]:
@@ -198,7 +203,7 @@ class Chatter(PartialChatter):
 
             changed in 2.1.0: return value is no longer optional. founders will now appear as subscribers
         """
-        return bool(self._sub) if self._sub is not None else "founder" in self.badges
+        return bool(self._sub) or "founder" in self.badges
 
     @property
     def prediction(self) -> Optional[PredictionEnum]:
