@@ -27,7 +27,8 @@ import inspect
 
 import itertools
 import copy
-from typing import Any, Union, Optional, Callable, Awaitable, Tuple, TYPE_CHECKING, Literal, List, Type, Set, TypeVar
+from typing import Any, Union, Optional, Callable, Awaitable, Tuple, TYPE_CHECKING, List, Type, Set, TypeVar
+from typing_extensions import Literal
 
 from twitchio.abcs import Messageable
 from .cooldowns import *
