@@ -3,7 +3,8 @@ import datetime
 import hmac
 import hashlib
 import logging
-from typing import Dict, TYPE_CHECKING, Optional, Type, Union, Literal
+from typing import Dict, TYPE_CHECKING, Optional, Type, Union
+from typing_extensions import Literal
 
 from aiohttp import web
 
@@ -18,7 +19,6 @@ try:
     def _loads(s: str) -> dict:
         return json.loads(s)
 
-
 except ModuleNotFoundError:
     import json
 
@@ -259,7 +259,7 @@ class ChannelCheerData(EventData):
 
     def __init__(self, client: EventSubClient, data: dict):
         self.is_anonymous: bool = data["is_anonymous"]
-        self.user: Optional[PartialUser] = self.is_anonymous and _transform_user(client, data, "user")
+        self.user: Optional[PartialUser] = _transform_user(client, data, "user") if not self.is_anonymous else None
         self.broadcaster = _transform_user(client, data, "broadcaster_user")
         self.message: str = data["message"]
         self.bits = int(data["bits"])
